package com.dayou.service.impl;

import com.dayou.dto.TaskRecordDTO;
import com.dayou.entity.AssetsProduction;
import com.dayou.mapper.AssetsProductionMapper;
import com.dayou.service.IAssetsProductionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.dayou.utils.ExcelUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.ArrayList;

import org.springframework.transaction.annotation.Transactional;
import com.dayou.enums.BatchTaskTypeEnum;

/**
 * <p>
 * 资产产品表 服务实现类
 * </p>
 *
 * @author GouGengquan
 * @since 2024-03-28
 */
@Service
public class AssetsProductionServiceImpl extends ServiceImpl<AssetsProductionMapper, AssetsProduction> implements IAssetsProductionService {

    @Autowired
    private AssetsProductionMapper assetsProductionMapper;

    /**
     * 根据资产业务id查询资产业务产品
     *
     * @param id 资产业务id
     * @return List<AssetsProduction>
     */
    @Override
    public List<AssetsProduction> getAroductionByAssetsId(Long id) {
        return this.list(new LambdaQueryWrapper<AssetsProduction>().eq(AssetsProduction::getBusinessId, id));
    }

    @Override
    @SuppressWarnings("unchecked")
    public Page<AssetsProduction> selectPage(Page page, AssetsProduction assetsProduction) {
        return this.page(page, new QueryWrapper<AssetsProduction>(assetsProduction));
    }


    @Override
    public AssetsProduction detail(Long id) {
        return this.getById(id);
    }

    @Override
    public Boolean add(TaskRecordDTO<AssetsProduction> taskRecordDTO) {
        return this.save(taskRecordDTO.getTaskData());
    }

    @Override
    public Boolean update(AssetsProduction assetsProduction) {
        return this.updateById(assetsProduction);
    }

    @Override
    public Boolean delete(Long id) {
        //逻辑删除
        return this.removeById(id);
    }

    /**
     * 根据业务id获取产品信息类型集合
     *
     * @param businessId 资产业务id
     * @return List<String>
     */
    public List<String> getProductionTypes(Long businessId) {
        return assetsProductionMapper.getProductionTypes(businessId);
    }
}
